pub struct TargetOptions {Show 16 fields
pub is_builtin: bool,
pub endian: Endian,
pub c_int_width: String,
pub os: String,
pub min_os_version: Option<(u32, u32, u32)>,
pub env: String,
pub abi: String,
pub vendor: String,
pub linker_flavor: LinkerFlavor,
pub pre_link_args: Vec<String>,
pub cpu: String,
pub features: String,
pub dll_prefix: String,
pub is_like_windows: bool,
pub is_like_msvc: bool,
pub is_like_osx: bool,
}Expand description
Optional aspects of target specification.
Fields
is_builtin: boolTrue if this is a built-in target
endian: EndianUsed as the target_endian cfg variable. Defaults to little endian.
c_int_width: StringWidth of c_int type
os: StringThe name of the OS
min_os_version: Option<(u32, u32, u32)>Minimum version of the OS to target
env: StringThe name of the environment
abi: StringABI name to distinguish multiple ABIs on the same OS and architecture. For instance, "eabi"
or "eabihf". Defaults to “”.
vendor: StringThe name of the vendor
linker_flavor: LinkerFlavorLinker flavor
pre_link_args: Vec<String>Linker arguments that are passed before any user-defined libraries.
cpu: StringDefault CPU to pass to LLVM. Corresponds to llc -mcpu=$cpu. Defaults to “generic”.
features: StringDefault target features to pass to LLVM. These features will always be passed, and cannot
be disabled even via -C. Corresponds to llc -mattr=$features.
dll_prefix: StringString to prepend to the name of every dynamic library. Defaults to “lib”.
is_like_windows: boolWhether the target toolchain is like Windows
is_like_msvc: boolis_like_osx: boolWhether the target toolchain is like macOS’s. Only useful for compiling against iOS/macOS,
in particular running dsymutil and some other stuff like -dead_strip. Defaults to false.